@@ -108,8 +108,12 @@
 #endif
 
 #ifndef HAVE_FINITE
+#ifdef HAVE_ISFINITE
+#define finite isfinite
+#else
 #define finite gsl_finite
 #endif
+#endif
 
 #ifdef __GNUC__
 #define DISCARD_POINTER(p) do { ; } while(p ? 0 : 0);
