@@ -24,9 +24,9 @@ FUNCTION(fft_halfcomplex,pass_4) (const BASE in[],
 				  const size_t ostride,
 				  const size_t product,
 				  const size_t n,
-				  const gsl_complex twiddle1[],
-				  const gsl_complex twiddle2[],
-				  const gsl_complex twiddle3[])
+				  const TYPE(gsl_complex) twiddle1[],
+				  const TYPE(gsl_complex) twiddle2[],
+				  const TYPE(gsl_complex) twiddle3[])
 {
   size_t i, j, k, k1, jump;
   size_t factor, q, m, product_1;
