@@ -50,12 +50,17 @@ typedef struct
 typedef struct
 {
   gsl_matrix_complex_long_double matrix;
-} gsl_matrix_complex_long_double_view;
+} _gsl_matrix_complex_long_double_view;
+
+typedef _gsl_matrix_complex_long_double_view gsl_matrix_complex_long_double_view;
 
 typedef struct
 {
-  const gsl_matrix_complex_long_double matrix;
-} gsl_matrix_complex_long_double_const_view;
+  gsl_matrix_complex_long_double matrix;
+} _gsl_matrix_complex_long_double_const_view;
+
+typedef const _gsl_matrix_complex_long_double_const_view gsl_matrix_complex_long_double_const_view;
+
 
 /* Allocation */
 
@@ -87,90 +92,90 @@ void gsl_matrix_complex_long_double_free (gsl_matrix_complex_long_double * m);
 
 /* Views */
 
-gsl_matrix_complex_long_double_view 
+_gsl_matrix_complex_long_double_view 
 gsl_matrix_complex_long_double_submatrix (gsl_matrix_complex_long_double * m, 
                             const size_t i, const size_t j, 
                             const size_t n1, const size_t n2);
 
-gsl_vector_complex_long_double_view 
+_gsl_vector_complex_long_double_view 
 gsl_matrix_complex_long_double_row (gsl_matrix_complex_long_double * m, const size_t i);
 
-gsl_vector_complex_long_double_view 
+_gsl_vector_complex_long_double_view 
 gsl_matrix_complex_long_double_column (gsl_matrix_complex_long_double * m, const size_t j);
 
-gsl_vector_complex_long_double_view 
+_gsl_vector_complex_long_double_view 
 gsl_matrix_complex_long_double_diagonal (gsl_matrix_complex_long_double * m);
 
-gsl_vector_complex_long_double_view 
+_gsl_vector_complex_long_double_view 
 gsl_matrix_complex_long_double_subdiagonal (gsl_matrix_complex_long_double * m, const size_t k);
 
-gsl_vector_complex_long_double_view 
+_gsl_vector_complex_long_double_view 
 gsl_matrix_complex_long_double_superdiagonal (gsl_matrix_complex_long_double * m, const size_t k);
 
-gsl_matrix_complex_long_double_view
+_gsl_matrix_complex_long_double_view
 gsl_matrix_complex_long_double_view_array (long double * base,
                              const size_t n1, 
                              const size_t n2);
 
-gsl_matrix_complex_long_double_view
+_gsl_matrix_complex_long_double_view
 gsl_matrix_complex_long_double_view_array_with_tda (long double * base, 
                                       const size_t n1, 
                                       const size_t n2,
                                       const size_t tda);
 
-gsl_matrix_complex_long_double_view
+_gsl_matrix_complex_long_double_view
 gsl_matrix_complex_long_double_view_vector (gsl_vector_complex_long_double * v,
                               const size_t n1, 
                               const size_t n2);
 
-gsl_matrix_complex_long_double_view
+_gsl_matrix_complex_long_double_view
 gsl_matrix_complex_long_double_view_vector_with_tda (gsl_vector_complex_long_double * v,
                                        const size_t n1, 
                                        const size_t n2,
                                        const size_t tda);
 
 
-gsl_matrix_complex_long_double_const_view 
+_gsl_matrix_complex_long_double_const_view 
 gsl_matrix_complex_long_double_const_submatrix (const gsl_matrix_complex_long_double * m, 
                                   const size_t i, const size_t j, 
                                   const size_t n1, const size_t n2);
 
-gsl_vector_complex_long_double_const_view 
+_gsl_vector_complex_long_double_const_view 
 gsl_matrix_complex_long_double_const_row (const gsl_matrix_complex_long_double * m, 
                             const size_t i);
 
-gsl_vector_complex_long_double_const_view 
+_gsl_vector_complex_long_double_const_view 
 gsl_matrix_complex_long_double_const_column (const gsl_matrix_complex_long_double * m, 
                                const size_t j);
 
-gsl_vector_complex_long_double_const_view
+_gsl_vector_complex_long_double_const_view
 gsl_matrix_complex_long_double_const_diagonal (const gsl_matrix_complex_long_double * m);
 
-gsl_vector_complex_long_double_const_view 
+_gsl_vector_complex_long_double_const_view 
 gsl_matrix_complex_long_double_const_subdiagonal (const gsl_matrix_complex_long_double * m, 
                                     const size_t k);
 
-gsl_vector_complex_long_double_const_view 
+_gsl_vector_complex_long_double_const_view 
 gsl_matrix_complex_long_double_const_superdiagonal (const gsl_matrix_complex_long_double * m, 
                                       const size_t k);
 
-gsl_matrix_complex_long_double_const_view
+_gsl_matrix_complex_long_double_const_view
 gsl_matrix_complex_long_double_const_view_array (const long double * base,
                                    const size_t n1, 
                                    const size_t n2);
 
-gsl_matrix_complex_long_double_const_view
+_gsl_matrix_complex_long_double_const_view
 gsl_matrix_complex_long_double_const_view_array_with_tda (const long double * base, 
                                             const size_t n1, 
                                             const size_t n2,
                                             const size_t tda);
 
-gsl_matrix_complex_long_double_const_view
+_gsl_matrix_complex_long_double_const_view
 gsl_matrix_complex_long_double_const_view_vector (const gsl_vector_complex_long_double * v,
                                     const size_t n1, 
                                     const size_t n2);
 
-gsl_matrix_complex_long_double_const_view
+_gsl_matrix_complex_long_double_const_view
 gsl_matrix_complex_long_double_const_view_vector_with_tda (const gsl_vector_complex_long_double * v,
                                              const size_t n1, 
                                              const size_t n2,
