@@ -49,12 +49,16 @@ typedef struct
 typedef struct
 {
   gsl_matrix_uint matrix;
-} gsl_matrix_uint_view;
+} _gsl_matrix_uint_view;
+
+typedef _gsl_matrix_uint_view gsl_matrix_uint_view;
 
 typedef struct
 {
-  const gsl_matrix_uint matrix;
-} gsl_matrix_uint_const_view;
+  gsl_matrix_uint matrix;
+} _gsl_matrix_uint_const_view;
+
+typedef const _gsl_matrix_uint_const_view gsl_matrix_uint_const_view;
 
 /* Allocation */
 
@@ -90,91 +94,91 @@ void gsl_matrix_uint_free (gsl_matrix_uint * m);
 
 /* Views */
 
-gsl_matrix_uint_view 
+_gsl_matrix_uint_view 
 gsl_matrix_uint_submatrix (gsl_matrix_uint * m, 
                             const size_t i, const size_t j, 
                             const size_t n1, const size_t n2);
 
-gsl_vector_uint_view 
+_gsl_vector_uint_view 
 gsl_matrix_uint_row (gsl_matrix_uint * m, const size_t i);
 
-gsl_vector_uint_view 
+_gsl_vector_uint_view 
 gsl_matrix_uint_column (gsl_matrix_uint * m, const size_t j);
 
-gsl_vector_uint_view 
+_gsl_vector_uint_view 
 gsl_matrix_uint_diagonal (gsl_matrix_uint * m);
 
-gsl_vector_uint_view 
+_gsl_vector_uint_view 
 gsl_matrix_uint_subdiagonal (gsl_matrix_uint * m, const size_t k);
 
-gsl_vector_uint_view 
+_gsl_vector_uint_view 
 gsl_matrix_uint_superdiagonal (gsl_matrix_uint * m, const size_t k);
 
-gsl_matrix_uint_view
+_gsl_matrix_uint_view
 gsl_matrix_uint_view_array (unsigned int * base,
                              const size_t n1, 
                              const size_t n2);
 
-gsl_matrix_uint_view
+_gsl_matrix_uint_view
 gsl_matrix_uint_view_array_with_tda (unsigned int * base, 
                                       const size_t n1, 
                                       const size_t n2,
                                       const size_t tda);
 
 
-gsl_matrix_uint_view
+_gsl_matrix_uint_view
 gsl_matrix_uint_view_vector (gsl_vector_uint * v,
                               const size_t n1, 
                               const size_t n2);
 
-gsl_matrix_uint_view
+_gsl_matrix_uint_view
 gsl_matrix_uint_view_vector_with_tda (gsl_vector_uint * v,
                                        const size_t n1, 
                                        const size_t n2,
                                        const size_t tda);
 
 
-gsl_matrix_uint_const_view 
+_gsl_matrix_uint_const_view 
 gsl_matrix_uint_const_submatrix (const gsl_matrix_uint * m, 
                                   const size_t i, const size_t j, 
                                   const size_t n1, const size_t n2);
 
-gsl_vector_uint_const_view 
+_gsl_vector_uint_const_view 
 gsl_matrix_uint_const_row (const gsl_matrix_uint * m, 
                             const size_t i);
 
-gsl_vector_uint_const_view 
+_gsl_vector_uint_const_view 
 gsl_matrix_uint_const_column (const gsl_matrix_uint * m, 
                                const size_t j);
 
-gsl_vector_uint_const_view
+_gsl_vector_uint_const_view
 gsl_matrix_uint_const_diagonal (const gsl_matrix_uint * m);
 
-gsl_vector_uint_const_view 
+_gsl_vector_uint_const_view 
 gsl_matrix_uint_const_subdiagonal (const gsl_matrix_uint * m, 
                                     const size_t k);
 
-gsl_vector_uint_const_view 
+_gsl_vector_uint_const_view 
 gsl_matrix_uint_const_superdiagonal (const gsl_matrix_uint * m, 
                                       const size_t k);
 
-gsl_matrix_uint_const_view
+_gsl_matrix_uint_const_view
 gsl_matrix_uint_const_view_array (const unsigned int * base,
                                    const size_t n1, 
                                    const size_t n2);
 
-gsl_matrix_uint_const_view
+_gsl_matrix_uint_const_view
 gsl_matrix_uint_const_view_array_with_tda (const unsigned int * base, 
                                             const size_t n1, 
                                             const size_t n2,
                                             const size_t tda);
 
-gsl_matrix_uint_const_view
+_gsl_matrix_uint_const_view
 gsl_matrix_uint_const_view_vector (const gsl_vector_uint * v,
                                     const size_t n1, 
                                     const size_t n2);
 
-gsl_matrix_uint_const_view
+_gsl_matrix_uint_const_view
 gsl_matrix_uint_const_view_vector_with_tda (const gsl_vector_uint * v,
                                              const size_t n1, 
                                              const size_t n2,
