@@ -19,21 +19,24 @@
 
 #include <config.h>
 #include <gsl/gsl_multimin.h>
-#include <gsl/gsl_blas_types.h>
 #include <gsl/gsl_blas.h>
 
 int
-gsl_multimin_test_gradient_sqr_norm(gsl_multimin_fdf_history *h,double epsabs)
+gsl_multimin_test_gradient (const gsl_vector *g, double epsabs)
 {
-  double sqr_norm;
+  double norm;
 
   if (epsabs < 0.0)
-    GSL_ERROR ("absolute tolerance is negative", GSL_EBADTOL);
+    {
+      GSL_ERROR ("absolute tolerance is negative", GSL_EBADTOL);
+    }
 
-  gsl_blas_ddot(h->g,h->g,&sqr_norm);
+  norm = gsl_blas_dnrm2(g);
   
-  if (sqr_norm<epsabs)
-    return GSL_SUCCESS;
+  if (norm < epsabs)
+    {
+      return GSL_SUCCESS;
+    }
 
   return GSL_CONTINUE;
 }
