@@ -18,7 +18,6 @@
  */
 
 /* Author:  G. Jungman
- * RCS:     $Id: evolve.c,v 1.11 2001/06/25 10:27:45 bjg Exp $
  */
 #include <config.h>
 #include <string.h>
@@ -125,7 +124,12 @@ gsl_odeiv_evolve_apply (gsl_odeiv_evolve * e,
 
   if (e->dimension != step->dimension)
     {
-      GSL_ERROR ("step dimension must match evolvution size", GSL_EINVAL);
+      GSL_ERROR ("step dimension must match evolution size", GSL_EINVAL);
+    }
+
+  if ((dt < 0.0 && h0 > 0.0) || (dt > 0.0 && h0 < 0.0))
+    {
+      GSL_ERROR ("step direction must match interval direction", GSL_EINVAL);
     }
 
   /* No need to copy if we cannot control the step size. */
@@ -144,11 +148,15 @@ gsl_odeiv_evolve_apply (gsl_odeiv_evolve * e,
 
 try_step:
     
-  if (h0 > dt)
+  if ((dt >= 0.0 && h0 > dt) || (dt < 0.0 && h0 < dt))
     {
       h0 = dt;
       final_step = 1;
     }
+  else
+    {
+      final_step = 0;
+    }
 
   if (step->type->can_use_dydt_in)
     {
