@@ -46,11 +46,9 @@ gsl_ran_chisq_pdf (const double x, const double nu)
   else
     {
       double p;
-      gsl_sf_result lngamma;
-
-      gsl_sf_lngamma_impl (nu / 2, &lngamma);
+      double lngamma = gsl_sf_lngamma (nu / 2);
       
-      p = exp ((nu / 2 - 1) * log (x/2) - x/2 - lngamma.val) / 2;
+      p = exp ((nu / 2 - 1) * log (x/2) - x/2 - lngamma) / 2;
       return p;
     }
 }
