@@ -1,6 +1,25 @@
+/* rng/transputer.c
+ * 
+ * Copyright (C) 1996, 1997, 1998, 1999, 2000 James Theiler, Brian Gough
+ * 
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or (at
+ * your option) any later version.
+ * 
+ * This program is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * General Public License for more details.
+ * 
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ */
+
 #include <config.h>
 #include <stdlib.h>
-#include <gsl_rng.h>
+#include <gsl/gsl_rng.h>
 
 /* This is the INMOS Transputer Development System generator. The sequence is,
 
@@ -13,9 +32,9 @@
 
    The period of this generator is 2^32. */
 
-inline unsigned long int transputer_get (void *vstate);
-double transputer_get_double (void *vstate);
-void transputer_set (void *state, unsigned long int s);
+static inline unsigned long int transputer_get (void *vstate);
+static double transputer_get_double (void *vstate);
+static void transputer_set (void *state, unsigned long int s);
 
 typedef struct
   {
@@ -23,7 +42,7 @@ typedef struct
   }
 transputer_state_t;
 
-unsigned long int
+static unsigned long int
 transputer_get (void *vstate)
 {
   transputer_state_t *state = (transputer_state_t *) vstate;
@@ -33,13 +52,13 @@ transputer_get (void *vstate)
   return state->x;
 }
 
-double
+static double
 transputer_get_double (void *vstate)
 {
   return transputer_get (vstate) / 4294967296.0 ;
 }
 
-void
+static void
 transputer_set (void *vstate, unsigned long int s)
 {
   transputer_state_t *state = (transputer_state_t *) vstate;
