@@ -36,8 +36,14 @@
 
 __BEGIN_DECLS
 
-void gsl_sort (double * data, size_t stride, size_t n);
-int gsl_sort_index (size_t * p, const double * data, size_t stride, size_t n);
+void gsl_sort (double * data, const size_t stride, const size_t n);
+void gsl_sort_index (size_t * p, const double * data, const size_t stride, const size_t n);
+
+int gsl_sort_smallest (double * dest, const size_t k, const double * src, const size_t stride, const size_t n);
+int gsl_sort_smallest_index (size_t * p, const size_t k, const double * src, const size_t stride, const size_t n);
+
+int gsl_sort_largest (double * dest, const size_t k, const double * src, const size_t stride, const size_t n);
+int gsl_sort_largest_index (size_t * p, const size_t k, const double * src, const size_t stride, const size_t n);
 
 __END_DECLS
 
