@@ -17,9 +17,8 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* Author:  G. Jungman
- * RCS:     $Id: bessel_Jnu.c,v 1.24 2001/07/11 15:19:50 bjg Exp $
- */
+/* Author:  G. Jungman */
+
 #include <config.h>
 #include <gsl/gsl_math.h>
 #include <gsl/gsl_errno.h>
@@ -119,7 +118,7 @@ gsl_sf_bessel_Jnu_e(const double nu, const double x, gsl_sf_result * result)
       
       double Ynm1 = Y_mu.val;
       double Yn   = Y_mup1.val;
-      double Ynp1;
+      double Ynp1 = 0.0;
       int n;
       for(n=1; n<N; n++) {
         Ynp1 = 2.0*(mu+n)/x * Yn - Ynm1;
