@@ -17,9 +17,8 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* Author:  G. Jungman
- * RCS:     $Id: bessel_i.c,v 1.22 2001/07/11 15:19:50 bjg Exp $
- */
+/* Author:  G. Jungman */
+
 #include <config.h>
 #include <gsl/gsl_math.h>
 #include <gsl/gsl_errno.h>
@@ -241,7 +240,7 @@ int gsl_sf_bessel_il_scaled_e(const int l, double x, gsl_sf_result * result)
     int stat_a2 = gsl_sf_bessel_Inu_scaled_asymp_unif_e(LMAX     + 0.5, x, &r_iell);
     double iellp1 = r_iellp1.val;
     double iell   = r_iell.val;
-    double iellm1;
+    double iellm1 = 0.0;
     int ell;
     iellp1 *= rt_term;
     iell   *= rt_term;
