@@ -17,9 +17,8 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* Author:  G. Jungman
- * RCS:     $Id: coulomb.c,v 1.49 2001/07/11 15:19:50 bjg Exp $
- */
+/* Author:  G. Jungman */
+
 /* Evaluation of Coulomb wave functions F_L(eta, x), G_L(eta, x),
  * and their derivatives. A combination of Steed's method, asymptotic
  * results, and power series.
@@ -125,7 +124,7 @@ gsl_sf_coulomb_CL_e(double lam, double eta, gsl_sf_result * result)
 /* cl[0] .. cl[kmax] = C_{lam_min}(eta) .. C_{lam_min+kmax}(eta)
  */
 int
-gsl_sf_coulomb_CL_list(double lam_min, int kmax, double eta, double * cl)
+gsl_sf_coulomb_CL_array(double lam_min, int kmax, double eta, double * cl)
 {
   int k;
   gsl_sf_result cl_0;
