@@ -493,7 +493,7 @@ main (void)
   }
 
 
-  return gsl_test_summary ();
+  exit (gsl_test_summary ());
 }
 
 
