@@ -184,20 +184,24 @@
 #if defined(BASE_DOUBLE)
 #define FUNCTION(dir,name) CONCAT3(dir,QUALIFIER,name)
 #define TYPE(dir) dir
+#define VIEW(dir,name) CONCAT2(dir,name)
 #define QUALIFIED_TYPE(dir) QUALIFIER dir
 #define QUALIFIED_VIEW(dir,name) CONCAT3(dir,QUALIFIER,name)
 #else
 #define FUNCTION(a,c) CONCAT4(a,SHORT,QUALIFIER,c)
 #define TYPE(dir) CONCAT2(dir,SHORT)
+#define VIEW(dir,name) CONCAT3(dir,SHORT,name)
 #define QUALIFIED_TYPE(dir) QUALIFIER CONCAT2(dir,SHORT)
 #define QUALIFIED_VIEW(dir,name) CONCAT4(dir,SHORT,QUALIFIER,name)
 #endif
 #if defined(BASE_GSL_COMPLEX)
 #define REAL_TYPE(dir) dir
+#define REAL_VIEW(dir,name) CONCAT2(dir,name)
 #define QUALIFIED_REAL_TYPE(dir) QUALIFIER dir
 #define QUALIFIED_REAL_VIEW(dir,name) CONCAT3(dir,QUALIFIER,name)
 #else
 #define REAL_TYPE(dir) CONCAT2(dir,SHORT_REAL)
+#define REAL_VIEW(dir,name) CONCAT3(dir,SHORT_REAL,name)
 #define QUALIFIED_REAL_TYPE(dir) QUALIFIER CONCAT2(dir,SHORT_REAL)
 #define QUALIFIED_REAL_VIEW(dir,name) CONCAT4(dir,SHORT_REAL,QUALIFIER,name)
 #endif
@@ -205,20 +209,24 @@
 #if defined(BASE_DOUBLE)
 #define FUNCTION(dir,name) CONCAT2(dir,name)
 #define TYPE(dir) dir
+#define VIEW(dir,name) CONCAT2(dir,name)
 #define QUALIFIED_TYPE(dir) TYPE(dir)
 #define QUALIFIED_VIEW(dir,name) CONCAT2(dir,name)
 #else
 #define FUNCTION(a,c) CONCAT3(a,SHORT,c)
 #define TYPE(dir) CONCAT2(dir,SHORT)
+#define VIEW(dir,name) CONCAT3(dir,SHORT,name)
 #define QUALIFIED_TYPE(dir) TYPE(dir)
 #define QUALIFIED_VIEW(dir,name) CONCAT3(dir,SHORT,name)
 #endif
 #if defined(BASE_GSL_COMPLEX)
 #define REAL_TYPE(dir) dir
+#define REAL_VIEW(dir,name) CONCAT2(dir,name)
 #define QUALIFIED_REAL_TYPE(dir) dir
 #define QUALIFIED_REAL_VIEW(dir,name) CONCAT2(dir,name)
 #else
 #define REAL_TYPE(dir) CONCAT2(dir,SHORT_REAL)
+#define REAL_VIEW(dir,name) CONCAT3(dir,SHORT_REAL,name)
 #define QUALIFIED_REAL_TYPE(dir) CONCAT2(dir,SHORT_REAL)
 #define QUALIFIED_REAL_VIEW(dir,name) CONCAT3(dir,SHORT_REAL,name)
 #endif
