@@ -49,12 +49,16 @@ gsl_vector_ushort;
 typedef struct
 {
   gsl_vector_ushort vector;
-} gsl_vector_ushort_view;
+} _gsl_vector_ushort_view;
+
+typedef _gsl_vector_ushort_view gsl_vector_ushort_view;
 
 typedef struct
 {
-  const gsl_vector_ushort vector;
-} gsl_vector_ushort_const_view;
+  gsl_vector_ushort vector;
+} _gsl_vector_ushort_const_view;
+
+typedef const _gsl_vector_ushort_const_view gsl_vector_ushort_const_view;
 
 
 /* Allocation */
@@ -76,39 +80,39 @@ void gsl_vector_ushort_free (gsl_vector_ushort * v);
 
 /* Views */
 
-gsl_vector_ushort_view 
+_gsl_vector_ushort_view 
 gsl_vector_ushort_view_array (unsigned short *v, size_t n);
 
-gsl_vector_ushort_view 
+_gsl_vector_ushort_view 
 gsl_vector_ushort_view_array_with_stride (unsigned short *base,
                                          size_t stride,
                                          size_t n);
 
-gsl_vector_ushort_const_view 
+_gsl_vector_ushort_const_view 
 gsl_vector_ushort_const_view_array (const unsigned short *v, size_t n);
 
-gsl_vector_ushort_const_view 
+_gsl_vector_ushort_const_view 
 gsl_vector_ushort_const_view_array_with_stride (const unsigned short *base,
                                                size_t stride,
                                                size_t n);
 
-gsl_vector_ushort_view 
+_gsl_vector_ushort_view 
 gsl_vector_ushort_subvector (gsl_vector_ushort *v, 
                             size_t i, 
                             size_t n);
 
-gsl_vector_ushort_view 
+_gsl_vector_ushort_view 
 gsl_vector_ushort_subvector_with_stride (gsl_vector_ushort *v, 
                                         size_t i,
                                         size_t stride,
                                         size_t n);
 
-gsl_vector_ushort_const_view 
+_gsl_vector_ushort_const_view 
 gsl_vector_ushort_const_subvector (const gsl_vector_ushort *v, 
                                   size_t i, 
                                   size_t n);
 
-gsl_vector_ushort_const_view 
+_gsl_vector_ushort_const_view 
 gsl_vector_ushort_const_subvector_with_stride (const gsl_vector_ushort *v, 
                                               size_t i, 
                                               size_t stride,
